@@ -21,7 +21,6 @@ from asdf import AsdfFile
 from asdf.fits_embed import AsdfInFits
 from asdf import schema as asdf_schema
 
-from . import ndmodel
 from . import filetype
 from . import fits_support
 from . import properties
@@ -52,7 +51,7 @@ _DEFAULT_SCHEMA = {
 }
 
 
-class DataModel(properties.ObjectNode, ndmodel.NDModel):
+class DataModel(properties.ObjectNode):
     """
     Base class of all of the data models.
     """
@@ -66,8 +65,8 @@ class DataModel(properties.ObjectNode, ndmodel.NDModel):
 
     def __init__(self, init=None, schema=None, memmap=False,
                  pass_invalid_values=None, strict_validation=None,
-                 validate_on_assignment=None,
-                 ignore_missing_extensions=True, **kwargs):
+                 validate_on_assignment=None, cast_fits_arrays=True,
+                 validate_arrays=False, ignore_missing_extensions=True, **kwargs):
         """
         Parameters
         ----------
@@ -121,6 +120,15 @@ class DataModel(properties.ObjectNode, ndmodel.NDModel):
             If 'False', schema validation occurs only once at the time of write.
             Validation errors generate warnings.
 
+        cast_fits_arrays : bool
+            If `True`, arrays will be cast to the dtype described by the schema
+            when read from a FITS file.
+            If `False`, arrays will be read without casting.
+
+        validate_arrays : bool
+            If `True`, arrays will be validated against ndim, max_ndim, and datatype
+            validators in the schemas.
+
         ignore_missing_extensions : bool
             When `False`, raise warnings when a file is read that
             contains metadata about extensions that are not available.
@@ -152,6 +160,8 @@ class DataModel(properties.ObjectNode, ndmodel.NDModel):
         self._strict_validation = strict_validation
         self._ignore_missing_extensions = ignore_missing_extensions
         self._validate_on_assignment = validate_on_assignment
+        self._cast_fits_arrays = cast_fits_arrays
+        self._validate_arrays = validate_arrays
 
         kwargs.update({'ignore_missing_extensions': ignore_missing_extensions})
 
@@ -167,6 +177,7 @@ class DataModel(properties.ObjectNode, ndmodel.NDModel):
 
         # Provide the object as context to other classes and functions
         self._ctx = self
+        self._parent = None
 
         # Initialize with an empty AsdfFile instance as this is needed for
         # reading in FITS files where validate._check_value() gets called, and
@@ -646,15 +657,9 @@ class DataModel(properties.ObjectNode, ndmodel.NDModel):
                 self._shape = primary_array.shape
         return self._shape
 
-    def my_attribute(self, attr):
-        properties = frozenset(("shape", "history", "_extra_fits", "schema"))
-        return attr in properties
-
     def __setattr__(self, attr, value):
-        if self.my_attribute(attr):
+        if attr in frozenset(("shape", "history", "_extra_fits", "schema")):
             object.__setattr__(self, attr, value)
-        elif ndmodel.NDModel.my_attribute(self, attr):
-            ndmodel.NDModel.__setattr__(self, attr, value)
         else:
             properties.ObjectNode.__setattr__(self, attr, value)
 
