@@ -43,6 +43,13 @@ class FitsModel(DataModel):
     schema_url = "http://example.com/schemas/fits_model"
 
 
+class PureFitsModel(FitsModel):
+
+    def __init__(self, init=None, **kwargs):
+        super().__init__(init=init, **kwargs)
+        self._no_asdf_extension = True
+
+
 class TransformModel(DataModel):
     """
     Model with an astropy.modeling model in one of its attributes.
@@ -55,3 +62,12 @@ class TableModel(DataModel):
     Model that includes a recarray-style table.
     """
     schema_url = "http://example.com/schemas/table_model"
+
+
+class DeprecatedModel(DataModel):
+    """
+    Model with a top-level "old_origin" property that has
+    moved to "meta.origin", and a "meta.old_data" property that has
+    moved to "data".
+    """
+    schema_url = "http://example.com/schemas/deprecated_model"
